---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
[Please provide a code sample here.]

**Expected behavior**
A clear and concise description of what you expected to happen.


**System (please complete the following information):**
 - OS: [e.g. iOS]
 - Environment [e.g. contents of conda environment]


**Additional context**
Add any other context about the problem here.
